@@ -16,16 +16,14 @@
  * 
  */
 
-#ifndef _IPMI_SENSORS_OEM_INTEL_H
-#define _IPMI_SENSORS_OEM_INTEL_H
+#ifndef IPMI_SENSORS_OEM_INTEL_H
+#define IPMI_SENSORS_OEM_INTEL_H
 
 #include "ipmi-sensors.h"
 
 int ipmi_sensors_oem_intel_output_oem_record (ipmi_sensors_state_data_t *state_data,
-					      const void *sdr_record,
-					      unsigned int sdr_record_len,
 					      uint32_t oem_record_manufacturer_id,
 					      const uint8_t *oem_data,
 					      unsigned int oem_data_len);
 
-#endif
+#endif /* IPMI_SENSORS_OEM_INTEL_H */
