@@ -32,8 +32,8 @@
  */
 
 /* file is "ipmiconsole_.h", so double underscore */
-#ifndef _IPMICONSOLE__H
-#define _IPMICONSOLE__H
+#ifndef IPMICONSOLE__H
+#define IPMICONSOLE__H
 
 #include <freeipmi/freeipmi.h>
 
@@ -54,7 +54,7 @@ enum ipmiconsole_argp_option_keys
 
 struct ipmiconsole_arguments
 {
-  struct common_cmd_args common;
+  struct common_cmd_args common_args;
   char escape_char;
   int dont_steal;
   int deactivate;
@@ -67,4 +67,4 @@ struct ipmiconsole_arguments
 #endif /* NDEBUG */
 };
 
-#endif /* _IPMICONSOLE__H */
+#endif /* IPMICONSOLE__H */
