@@ -16,8 +16,8 @@
  * 
  */
 
-#ifndef _IPMI_SENSOR_TYPES_OEM_SPEC_H
-#define _IPMI_SENSOR_TYPES_OEM_SPEC_H
+#ifndef IPMI_SENSOR_TYPES_OEM_SPEC_H
+#define IPMI_SENSOR_TYPES_OEM_SPEC_H
 
 #ifdef __cplusplus
 extern "C" {
@@ -142,8 +142,18 @@ extern "C" {
 /* achu: not official names, named based on use context */
 #define IPMI_SENSOR_TYPE_OEM_SUPERMICRO_CPU_TEMP 0xC0 
 
+/******************************************* 
+ * Wistron                                 *
+ *******************************************/
+
+/*
+ * Wistron / Dell Poweredge C6220
+ */
+
+#define IPMI_SENSOR_TYPE_OEM_WISTRON_IOH_CORE_ERROR 0xC0
+
 #ifdef __cplusplus
 }
 #endif
 
-#endif
+#endif /* IPMI_SENSOR_TYPES_OEM_SPEC_H */
