@@ -16,8 +16,8 @@
  * 
  */
 
-#ifndef _IPMI_BMC_WATCHDOG_TIMER_CMDS_TEMPLATES_H
-#define _IPMI_BMC_WATCHDOG_TIMER_CMDS_TEMPLATES_H
+#ifndef IPMI_BMC_WATCHDOG_TIMER_CMDS_TEMPLATES_H
+#define IPMI_BMC_WATCHDOG_TIMER_CMDS_TEMPLATES_H
 
 #ifdef __cplusplus
 extern "C" {
@@ -144,4 +144,4 @@ FIID Template: tmpl_cmd_get_watchdog_timer_rs
 }
 #endif
 
-#endif  /* _IPMI_BMC_WATCHDOG_TIMER_CMDS_TEMPLATES_H */
+#endif /* IPMI_BMC_WATCHDOG_TIMER_CMDS_TEMPLATES_H */
