@@ -308,22 +308,37 @@ ipmiconsole_check_command (ipmiconsole_ctx_t c, ipmiconsole_packet_type_t p)
     }
   cmd = val;
 
-  if (p == IPMICONSOLE_PACKET_TYPE_GET_AUTHENTICATION_CAPABILITIES_RS)
-    expected_cmd = IPMI_CMD_GET_CHANNEL_AUTHENTICATION_CAPABILITIES;
-  else if (p == IPMICONSOLE_PACKET_TYPE_SET_SESSION_PRIVILEGE_LEVEL_RS)
-    expected_cmd = IPMI_CMD_SET_SESSION_PRIVILEGE_LEVEL;
-  else if (p == IPMICONSOLE_PACKET_TYPE_GET_CHANNEL_PAYLOAD_SUPPORT_RS)
-    expected_cmd = IPMI_CMD_GET_CHANNEL_PAYLOAD_SUPPORT;
-  else if (p == IPMICONSOLE_PACKET_TYPE_GET_PAYLOAD_ACTIVATION_STATUS_RS)
-    expected_cmd = IPMI_CMD_GET_PAYLOAD_ACTIVATION_STATUS;
-  else if (p == IPMICONSOLE_PACKET_TYPE_ACTIVATE_PAYLOAD_RS)
-    expected_cmd = IPMI_CMD_ACTIVATE_PAYLOAD;
-  else if (p == IPMICONSOLE_PACKET_TYPE_GET_CHANNEL_PAYLOAD_VERSION_RS)
-    expected_cmd = IPMI_CMD_GET_CHANNEL_PAYLOAD_VERSION;
-  else if (p == IPMICONSOLE_PACKET_TYPE_DEACTIVATE_PAYLOAD_RS)
-    expected_cmd = IPMI_CMD_DEACTIVATE_PAYLOAD;
-  else /* p == IPMICONSOLE_PACKET_TYPE_CLOSE_SESSION_RS */
-    expected_cmd = IPMI_CMD_CLOSE_SESSION;
+  switch (p)
+    {
+    case IPMICONSOLE_PACKET_TYPE_GET_AUTHENTICATION_CAPABILITIES_RS:
+      expected_cmd = IPMI_CMD_GET_CHANNEL_AUTHENTICATION_CAPABILITIES;
+      break;
+    case IPMICONSOLE_PACKET_TYPE_SET_SESSION_PRIVILEGE_LEVEL_RS:
+      expected_cmd = IPMI_CMD_SET_SESSION_PRIVILEGE_LEVEL;
+      break;
+    case IPMICONSOLE_PACKET_TYPE_GET_CHANNEL_PAYLOAD_SUPPORT_RS:
+      expected_cmd = IPMI_CMD_GET_CHANNEL_PAYLOAD_SUPPORT;
+      break;
+    case IPMICONSOLE_PACKET_TYPE_GET_PAYLOAD_ACTIVATION_STATUS_RS:
+      expected_cmd = IPMI_CMD_GET_PAYLOAD_ACTIVATION_STATUS;
+      break;
+    case IPMICONSOLE_PACKET_TYPE_ACTIVATE_PAYLOAD_RS:
+      expected_cmd = IPMI_CMD_ACTIVATE_PAYLOAD;
+      break;
+    case IPMICONSOLE_PACKET_TYPE_GET_CHANNEL_PAYLOAD_VERSION_RS:
+      expected_cmd = IPMI_CMD_GET_CHANNEL_PAYLOAD_VERSION;
+      break;
+    case IPMICONSOLE_PACKET_TYPE_DEACTIVATE_PAYLOAD_RS:
+      expected_cmd = IPMI_CMD_DEACTIVATE_PAYLOAD;
+      break;
+    case IPMICONSOLE_PACKET_TYPE_CLOSE_SESSION_RS:
+      expected_cmd = IPMI_CMD_CLOSE_SESSION;
+      break;
+    default:
+      IPMICONSOLE_CTX_DEBUG (c, ("invalid packet type: p = %d", p));
+      ipmiconsole_ctx_set_errnum (c, IPMICONSOLE_ERR_INTERNAL_ERROR);
+      return (-1);
+    }
 
   if (cmd != expected_cmd)
     IPMICONSOLE_CTX_DEBUG (c, ("command check failed; p = %d; cmd = %Xh; expected_cmd = %Xh", p, cmd, expected_cmd));
